#' Merge data
#'
#' Merge keys that allow to easily combine aggregate data from 
#' swissvotes with post-ballot surveys (VOX).
#'
#' @docType data
#'
#' @usage data(keys)
#'
#' @keywords datasets
#'
#' @source Walder, Maxime ([Twitter](https://twitter.com/WalderMaxime))
#'
#' @examples
#' data(keys)
#' bsnr <- keys$bfsnr
#' voxnr <- keys$projetx
"keys"